@@ -33,15 +33,15 @@ rr <- function(Tb)
   CE = Tb[2,2];
   CU = Tb[1,2];
   TO = TE + TU;
-  
+
   RE = CE / TE;
   RU = CU / TU;
-  
+
   RR  = RE/RU;
   CI = computeRiskCI(RR, CE, TE, CU, TU);
   RRCIL = CI[1];
   RRCIH = CI[2];
-  
+
   return(c(RR, RRCIL, RRCIH))
 }
 
@@ -82,7 +82,7 @@ CC_PAR <- function(C)
 
 CC_STATS <- function(C)
 {
-  .T = epi.2by2(dat=C, method="case.control", outcome="as.columns", homogeneity="woolf");
+  .T = epi.2by2(dat=C, method="case.control", outcome="as.columns");
   S <- summary(.T);
   return(S);
 }
@@ -120,7 +120,7 @@ computeDiffRiskCI <- function(RE, RU, NE, NU)
   D = 1.96*sqrt(B + C);
   R1 = A + D;
   R2 = A - D;
-  
+
   return(c(R2, R1));
 }
 
@@ -135,36 +135,36 @@ GetStrateVector <- function(A) {
   TS = TE + TU   ; # Total strate
   H  = HU + HE   ; # Total healthy
   C  = CU + CE   ; # Total cases
-  
+
   c(CE, CU, HE, HU, TE, TU, TS, H, C)
 }
 
 MANTEL_RR <- function(M) {
   colnames(M) <- c("CE", "CU", "HE", "HU", "TE", "TU", "TS", "H", "C")
   df <- data.frame(M)
-  
+
   R1 = sum((df$CE * df$TU) / df$TS)
   R2 = sum((df$CU * df$TE) / df$TS)
   rrmh = R1 / R2
-  
+
   R <- vector()
   for(I in 1:nrow(df)) {
     d2 = df[I, "TS"]^2
     V = ((df[I,"C"]*df[I,"TE"]*df[I,"TU"]) - (df[I,"CE"]*df[I,"CU"]*df[I,"TS"])) / d2
     R <- c(R, V)
   }
-  
+
   NUMER = sum(R)
   DENOM = R1 * R2
   RES = sqrt(NUMER / DENOM)
 
   L = log(rrmh) - (1.96 * RES);
   H = log(rrmh) + (1.96 * RES);
-    
+
   CIL = exp(L);
   CIH = exp(H);
 
-  c(rrmh, CIL, CIH)  
+  c(rrmh, CIL, CIH)
 }
 
 CMHrr <- function(A, B)
@@ -180,7 +180,7 @@ CMHrr <- function(A, B)
   T1  = Te1 + Tu1 ; # Total strate 1
   H1  = Hu1 + He1 ; # Total healthy
   C1  = Cu1 + Ce1 ; # Total cases
-  
+
   # Stratum 2 =====================
   Ce2 = B[2,2]    ; # Cases exposed
   Cu2 = B[1,2]    ; # Cases unexposed
@@ -192,31 +192,31 @@ CMHrr <- function(A, B)
   T2  = Te2 + Tu2 ; # Total strate 2
   H2  = Hu2 + He2 ; # Total healthy
   C2  = Cu2 + Ce2 ; # Total cases
-  
-  
+
+
 
   R1 = ((Ce1 * Tu1) / T1) + ((Ce2 * Tu2) / T2);
   R2 = ((Cu1 * Te1) / T1) + ((Cu2 * Te2) / T2);
   rrmh = R1 / R2;
 
   R3 = ((C1*Te1*Tu1) - (Ce1*Cu1*T1)) / T1^2;
-  R4 = ((C2*Te2*Tu2) - (Ce2*Cu2*T2)) / T2^2; 
+  R4 = ((C2*Te2*Tu2) - (Ce2*Cu2*T2)) / T2^2;
   R5 = R3 + R4;
   R6 = R5 / (R1 * R2);
   R7 = sqrt(R6);
-  
+
   L = log(rrmh) - (1.96 * R7);
   H = log(rrmh) + (1.96 * R7);
-  
+
   CIL = exp(L);
   CIH = exp(H);
-  
+
   return(c(rrmh, CIL, CIH));
 }
 
 MH_HomogeneityTest <- function(mht)
 {
-  T = epi.2by2(dat=mht, homogeneity="woolf");
+  T = epi.2by2(dat=mht);
   print(summary(T))
   S <- summary(T);
   return(c(S$RR.homog[1], S$RR.homog[3]));
@@ -251,7 +251,7 @@ getVarsList <- function(list) {
 #    cat("2 ===> ", ret, "\n")
     return(ret)
   }
-  
+
   if (.mode == "character" | .mode == "numeric") {
     ret <- c()
     for (v in input) {
